@@ -147,16 +147,78 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
         output = output,
         verbose = verbose
       )
-      if (output == "full_table") {
-        orgs <- orgs |>
-          graphql_engine$prepare_orgs_table()
-        private$orgs <- dplyr::pull(orgs, path)
+      if (inherits(orgs, "graphql_error")) {
+        if (verbose) {
+          cli::cli_alert_info("Switching to REST API")
+        }
+        orgs <- rest_engine$get_orgs(
+          orgs_count = as.integer(orgs_count),
+          verbose = verbose
+        )
+        if (output == "full_table") {
+          orgs <- orgs |>
+            rest_engine$prepare_orgs_table()
+          private$orgs <- dplyr::pull(orgs, path)
+        } else {
+          orgs <- purrr::map_vec(orgs, ~.$full_path)
+          private$orgs <- orgs
+        }
       } else {
-        private$orgs <- orgs
+        if (output == "full_table") {
+          orgs <- orgs |>
+            graphql_engine$prepare_orgs_table()
+          private$orgs <- dplyr::pull(orgs, path)
+        } else {
+          private$orgs <- orgs
+        }
       }
       return(orgs)
     },
 
+    get_orgs_from_orgs_and_repos = function(output, verbose) {
+      graphql_engine <- private$engines$graphql
+      default_engine <- graphql_engine
+      rest_engine <- private$engines$rest
+      orgs_names <- NULL
+      orgs_names_from_repos <- NULL
+      if ("org" %in% private$searching_scope) {
+        orgs_names <- purrr::keep(private$orgs, function(org) {
+          type <- attr(org, "type") %||% "organization"
+          type == "organization"
+        })
+      }
+      if ("repo" %in% private$searching_scope) {
+        orgs_names_from_repos <- graphql_engine$set_owner_type(
+          owners = names(private$orgs_repos)
+        ) |>
+          purrr::keep(function(org) {
+            type <- attr(org, "type") %||% "organization"
+            type == "organization"
+          })
+      }
+      total_orgs_names <- c(orgs_names, orgs_names_from_repos)
+      orgs_list <- purrr::map(total_orgs_names, function(org) {
+        type <- attr(org, "type") %||% "organization"
+        org_response <- graphql_engine$get_org(
+          org = utils::URLdecode(org),
+          verbose = verbose
+        )
+        if (inherits(org_response, "graphql_error")) {
+          if (verbose) {
+            cli::cli_alert_info("Switching to REST API")
+          }
+          org_response <- rest_engine$get_org(
+            org = utils::URLencode(org, reserved = TRUE),
+            verbose = verbose
+          )
+          default_engine <<- rest_engine
+        }
+        return(org_response)
+      })
+      orgs_table <- default_engine$prepare_orgs_table(orgs_list)
+      return(orgs_table)
+    },
+
     get_repos_ids = function(search_response) {
       purrr::map_vec(search_response, ~.$project_id) |> unique()
     },
@@ -273,10 +335,11 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
     # Use repositories either from parameter or, if not set, pull them from API
     get_repos_names = function(org) {
       graphql_engine <- private$engines$graphql
-      type <- attr(org, "type") %||% "organization"
+      owner_type <- attr(org, "type") %||% "organization"
       repos_names <- graphql_engine$get_repos_from_org(
         org = utils::URLdecode(org),
-        type = type
+        owner_type = owner_type,
+        verbose = verbose
       ) |>
         purrr::map_vec(~ .$node$repo_path)
       return(repos_names)
@@ -310,10 +373,10 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
               information = glue::glue("Pulling files content: [{paste0(file_path, collapse = ', ')}]")
             )
           }
-          type <- attr(org, "type") %||% "organization"
+          owner_type <- attr(org, "type") %||% "organization"
           graphql_engine$get_files_from_org_per_repo(
             org = org,
-            type = type,
+            owner_type = owner_type,
             repos = private$orgs_repos[[org]],
             file_paths = file_path,
             verbose = verbose,
@@ -347,10 +410,10 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
             information = "Pulling files from files structure"
           )
         }
-        type <- attr(org, "type") %||% "organization"
+        owner_type <- attr(org, "type") %||% "organization"
         graphql_engine$get_files_from_org_per_repo(
           org = org,
-          type = type,
+          owner_type = owner_type,
           repos = repos,
           host_files_structure = files_structure,
           verbose = verbose,
