@@ -7,7 +7,7 @@ globalVariables(c(
   "contributors_n", "githost"
 ))
 
-text_ext_files <- "\\.(txt|md|qmd|Rmd|markdown|yaml|yml|csv|json|xml|html|htm|css|js|r|py|sh|bat|ini|conf|log|sql|tsv|mdx)$"
+text_ext_files <- "\\.(txt|md|qmd|Rmd|markdown|yaml|yml|csv|json|xml|html|htm|css|js|R|r|py|sh|bat|ini|conf|log|sql|tsv|mdx)$"
 no_ext_files <- "^[^\\.]+$"
 
 text_files_pattern <- paste0("(", text_ext_files, "|", no_ext_files, ")")
